<?php
namespace EMS\PortalFuncionario\Geral\Repository;

use Zeedhi\Framework\Controller\Crud;
use Doctrine\ORM\EntityManager;
use Doctrine\DBAL\Connection;

use EMS\PortalFuncionario\Geral\Services\OperadorService;

class OperadorRepository extends Crud {
    /** @var Connection */
    protected $connection;

    public function __construct(EntityManager $entityManager) {
        $this->entityManager = $entityManager;
        $this->connection = $entityManager->getConnection();
    }

    public function get(
        int $nrOrg,
        string $cdOperador
    ) {
        $sql = <<<SQL
            SELECT
                *
            FROM
                OPERADOR
            WHERE
                CDOPERADOR = :P_CDOPERADOR AND
                NRORG = :P_NRORG
SQL;

        $params = [
            'P_NRORG' => $nrOrg,
            'P_CDOPERADOR' => $cdOperador,
        ];

        $stmt = $this->connection->prepare($sql);
        $stmt->execute($params);

        $result = $stmt->fetch();
        return $result;
    }

    public function getDadosOperador(
        string $cdOperador,
        string $dtNascPessoa        = null,
        string $dtAdmissaoVinc      = null,
        string $cpfPessoa           = null,
        string $idConfirmrecsenport = null
    ) {
        try {
            $sql = <<<SQL
                SELECT
                    VM.NRVINCULOM,
                    VM.NRORG,
                    VM.NRTIPOVINCULOM,
                    VH.NRESTRUTLEGAL,
                    VH.NRESTRUTGEREN,
                    EH.NMESCALATRABH,
                    ESH.NMRAZSOCESTRUT,
                    EH.PRIENTRADA,
                    EH.PRISAIDA,
                    EH.SEGENTRADA,
                    EH.SEGSAIDA,
                    PO.IDCONFIRMRECSENPORT,
                    PO.IDREALIZACADAUTOM,
                    PO.IDEXIGEAPROVMARCPF,
                    PO.IDEXIBEALMOCOMARCPF,
                    OP.DSEMAILOPER,
                    PH.NRCPFPESSOA
                FROM
                    GPE_VINCULOM      VM
                    JOIN GPE_VINCULOH      VH ON VH.NRORG = VM.NRORG
                                            AND VH.NRVINCULOM = VM.NRVINCULOM
                                            AND VH.DTMESCOMPETENC = (
                        SELECT
                            MAX(VHH.DTMESCOMPETENC)
                        FROM
                            GPE_VINCULOH VHH
                        WHERE
                            VHH.NRORG = VH.NRORG
                            AND VHH.NRVINCULOM = VH.NRVINCULOM
                    )
                    JOIN GPE_PESSOA        PM ON PM.NRORG = VM.NRORG
                                        AND PM.NRPESSOA = VM.NRPESSOA
                    JOIN GPE_PESSOAH       PH ON PH.NRORG = VM.NRORG AND PH.NRPESSOA = PM.NRPESSOA AND PH.DTMESCOMPETENC = (
                        SELECT MAX(DTMESCOMPETENC) FROM GPE_PESSOAH WHERE NRORG = PH.NRORG AND NRPESSOA = PH.NRPESSOA
                    )
                    JOIN OPERADOR          OP ON OP.NRORG = VM.NRORG
                                        AND OP.NRPARCNEGOCIO = PM.NRPARCNEGOCIO AND OP.CDOPERADOR = :P_CDOPERADOR
                    JOIN ESTRUTURAM        ESM ON ESM.NRORG = VM.NRORG
                                        AND ESM.NRESTRUTURAM = VH.NRESTRUTGEREN
                    JOIN ESTRUTURAH        ESH ON ESH.NRORG = VM.NRORG
                                        AND ESH.NRESTRUTURAM = VH.NRESTRUTGEREN
                                        AND ESH.DTMESCOMPETENC = (
                        SELECT
                            MAX(ESHH.DTMESCOMPETENC)
                        FROM
                            ESTRUTURAH ESHH
                        WHERE
                            ESHH.NRORG = ESH.NRORG
                            AND ESHH.NRESTRUTURAM = VH.NRESTRUTGEREN
                    )
                    JOIN GPE_ALTEESCALA   AE ON AE.NRORG = VM.NRORG AND AE.NRVINCULOM = VM.NRVINCULOM AND AE.DTINIESCALA = (
                        SELECT MAX(DTINIESCALA) FROM GPE_ALTEESCALA
                        WHERE GPE_ALTEESCALA.DTINIESCALA <= TRUNC(SYSDATE)
                          AND GPE_ALTEESCALA.NRVINCULOM = AE.NRVINCULOM
                          AND GPE_ALTEESCALA.NRORG = AE.NRORG
                    )
                    JOIN GPE_ESCALATRABM   EM ON EM.NRORG = VM.NRORG
                                            AND EM.NRESCALATRABM = AE.NRESCALATRABM
                    JOIN GPE_ESCALATRABH   EH ON EM.NRESCALATRABM = EH.NRESCALATRABM
                                            AND EM.NRORG = EH.NRORG
                                            AND EH.IDATIVO = 'S'
                                            AND EH.DTMESCOMPETENC = (
                        SELECT
                            MAX(DTMESCOMPETENC)
                        FROM
                            GPE_ESCALATRABH
                        WHERE
                            NRORG = EH.NRORG
                            AND NRESCALATRABM = EH.NRESCALATRABM
                            AND DTMESCOMPETENC <= SYSDATE
                            AND ( EM.DTFIMVIGENCIA >= SYSDATE
                                OR EM.DTFIMVIGENCIA IS NULL )
                    )
                    JOIN GPE_PARAMORG      PO ON PO.NRORG = VM.NRORG

                    WHERE 
                        VM.DTADMISSAOVINC <= TRUNC(SYSDATE)
                        AND (VM.DTRESCISAOVINC >= TRUNC(SYSDATE) OR VM.DTRESCISAOVINC IS NULL)

                        /* VALIDATIONS IF PROVIDED */
                        AND (TO_CHAR(VM.DTADMISSAOVINC, 'DD/MM/YYYY')   = :P_DTADMISSAOVINC         OR :P_DTADMISSAOVINC        IS NULL)
                        AND (TO_CHAR(PH.DTNASCPESSOA, 'DD/MM/YYYY')     = :P_DTNASCPESSOA           OR :P_DTNASCPESSOA          IS NULL)
                        AND (PH.NRCPFPESSOA                             = :P_NRCPFPESSOA            OR :P_NRCPFPESSOA           IS NULL)
                        AND (PO.IDCONFIRMRECSENPORT                     = :P_IDCONFIRMRECSENPORT    OR :P_IDCONFIRMRECSENPORT   IS NULL)
SQL;
            $query = $this->entityManager->getConnection()->prepare($sql);
    
            $query->execute(
                array(
                    "P_CDOPERADOR"          => $cdOperador,
                    "P_DTADMISSAOVINC"      => $dtAdmissaoVinc,
                    "P_DTNASCPESSOA"        => $dtNascPessoa,
                    "P_NRCPFPESSOA"         => $cpfPessoa,
                    "P_IDCONFIRMRECSENPORT" => $idConfirmrecsenport,
                )
            );
            return $query->fetchAll();
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function validaLogin(string $nrvinculom, string $nrorg) {
        try {
            $sql = <<<SQL
                SELECT
                    1
                FROM
                    GPE_VINCULOM VM
                WHERE
                    VM.NRORG = :P_NRORG
                    and VM.NRVINCULOM = :P_NRVINCULOM
                    and VM.DTADMISSAOVINC <= TRUNC(SYSDATE)
                    AND (VM.DTRESCISAOVINC >= TRUNC(SYSDATE) OR VM.DTRESCISAOVINC IS NULL)
SQL;
            $query = $this->entityManager->getConnection()->prepare($sql);
    
            $query->execute(
                array(
                    "P_NRVINCULOM" => $nrvinculom,
                    "P_NRORG" => $nrorg
                )
            );
            return $query->fetchAll();
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function getClientSecret(array $params): array {
        $sql = <<<SQL
            SELECT CLIENT_SECRET
            FROM ORGANIZACAO
            WHERE NRORG = :P_NRORG
SQL;

        $std = $this->connection->prepare($sql);
        $std->execute($params);
        $result = $std->fetchAll();

        return $result;
    }

    public function getBeforeForgotPasswordInfo(array $params) {
        $sql = <<<SQL
            SELECT
                OP.NRORG,
                OP.CDOPERADOR,
                OP.DSEMAILOPER,
                OP.NMACESSO,
                PO.IDCONFIRMRECSENPORT AS SHOW_CONFIRMATION_RESET
            FROM OPERADOR OP
            JOIN GPE_PARAMORG PO ON PO.NRORG = OP.NRORG
            WHERE UPPER(OP.NMACESSO) = UPPER(:P_DSEMAILOPER) /* LOGIN OPERATOR SEARCH */
                OR OP.DSEMAILOPER = :P_DSEMAILOPER
SQL;

        $std = $this->connection->prepare($sql);
        $std->execute($params);

        $dadosOperador = $std->fetch();

        return empty($dadosOperador) ? [] : $dadosOperador;
    }

    public function clearOperatorPassword(array $params) {
        $sql = <<<SQL
            UPDATE OPERADOR
            SET CDSENHAOPERWEB = :P_CDSENHAOPERWEB
            WHERE CDOPERADOR = :P_CDOPERADOR AND NRORG = :P_NRORG
SQL;

        $params['P_CDSENHAOPERWEB'] = OperadorService::OPERATOR_DEFAULT_HASH;

        $std = $this->connection->prepare($sql);
        return $std->execute($params);
    }
}
