<?php
namespace EMS\PortalFuncionario\Geral\Repository;

use Zeedhi\Framework\Controller\Crud;
use Doctrine\ORM\EntityManager;

use EMS\PortalFuncionario\Util\DateUtil;

class SolicitacaoRepository {

    public function __construct(EntityManager $entityManager) {
        $this->entityManager = $entityManager;
    }

    public function getSolicitacao(
        string $nrvinculom,
        string $nrorg,
        string $cdoperador,
        string $dtmescompetenc = null
    ) {
        $nrorgPadrao    = 0;
        $dtmescompetenc = empty($dtmescompetenc) ? DateUtil::getPrimeiroDiaDoMes(DateUtil::getDataAtual())->format('Y-m-d') : null;

        $sql = <<<SQL
            SELECT TO_CHAR(SL.DTSOLICITACAO, 'DD/MM/YYYY') AS DATASOLI,
              SL.*,
              VM_S.NMVINCULOM,
              EH.NRESTRUTURAH,
              EH.NRPARCRESPINF    AS NRPARCNEGOCIOESTRUT,
              OPERAPRI.NMOPERADOR AS NMOPERADORPRI,
              OPERASEC.NMOPERADOR AS NMOPERADORSEC,
              TP.NMTIPOSOLICITACAO,
              PE_R.NRPARCNEGOCIO,
              PS.NRNIVELAPROVASOLI,
              PS.NRPERFACESAPROVPRI,
              PS.NRPERFACESAPROVSEC,
              PE_R.NRPARCNEGOCIO,
              EH.NRPARCRESPINF,
              DECODE(PE_R.NRPARCNEGOCIO, EH.NRPARCRESPINF , 'S', 'N') AS IDRESPESTRUT
            FROM GPE_SOLICITACAO SL
                LEFT JOIN GPE_TIPOSOLICITACAO TP
                    ON SL.NRTIPOSOLICITACAO = TP.NRTIPOSOLICITACAO
                LEFT JOIN OPERADOR OPERAPRI
                    ON SL.CDOPERAPROVPRI = OPERAPRI.CDOPERADOR
                    AND OPERAPRI.NRORG   = SL.NRORG
                LEFT JOIN OPERADOR OPERASEC
                    ON SL.CDOPERAPROVSEC = OPERASEC.CDOPERADOR
                    AND OPERASEC.NRORG   = SL.NRORG
                LEFT JOIN GPE_PERFACESTIPOSOLI PS
                    ON PS.NRORG              = SL.NRORG
                    AND PS.NRTIPOSOLICITACAO = SL.NRTIPOSOLICITACAO
                LEFT JOIN GPE_VINCULOM VM_S
                    ON VM_S.NRORG       = SL.NRORG
                    AND VM_S.NRVINCULOM = SL.NRVINCULOM
                LEFT JOIN GPE_VINCULOH VH_S
                    ON VH_S.NRORG           = VM_S.NRORG
                    AND VH_S.NRVINCULOM     = VM_S.NRVINCULOM
                    AND VH_S.DTMESCOMPETENC =
                      (SELECT MAX(DTMESCOMPETENC)
                        FROM GPE_VINCULOH V1
                            WHERE V1.NRORG         = VH_S.NRORG
                            AND V1.NRVINCULOM      = VH_S.NRVINCULOM
                            AND V1.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                      )
                LEFT JOIN ESTRUTURAH EH
                    ON EH.NRORG           = VH_S.NRORG
                    AND EH.NRESTRUTURAM   = VH_S.NRESTRUTGEREN
                    AND EH.DTMESCOMPETENC =
                      (SELECT MAX(DTMESCOMPETENC)
                        FROM ESTRUTURAH H1
                            WHERE H1.NRORG         = EH.NRORG
                            AND H1.NRESTRUTURAM    = EH.NRESTRUTURAM
                            AND H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                      )
                LEFT JOIN OPERADOR OP
                    ON OP.NRORG       = SL.NRORG
                    AND OP.CDOPERADOR = :P_CDOPERADOR
                LEFT JOIN GPE_PESSOA PE_R
                    ON PE_R.NRPARCNEGOCIO  = OP.NRPARCNEGOCIO
                    AND PE_R.NRORG         = SL.NRORG
                WHERE(SL.NRORG         = :P_NRORG
                OR SL.NRORG            = :P_NRORG_PADRAO)
                AND SL.CDOPERINCLUSAO = :P_CDOPERADOR
                AND SL.NRVINCULOM = :P_NRVINCULOM
                ORDER BY NRSOLICITACAO ASC
SQL;
        $query = $this->entityManager->getConnection()->prepare($sql);

        $query->execute(
            array(
                'P_NRORG_PADRAO'    => $nrorgPadrao,
                'P_NRORG'           => $nrorg,
                'P_CDOPERADOR'      => $cdoperador,
                'P_DTMESCOMPETENC'  => $dtmescompetenc,
                'P_NRVINCULOM'      => $nrvinculom
            )
        );
        $solicitacao = $query->fetchAll();
        return $solicitacao;
    }

}