<?php
namespace Teknisa\Model\Gestaopessoas\Repositories;


class GerVerificacao extends \Doctrine\ORM\EntityRepository {

    public static function getQueryFeriasVencer3Meses()
    {
        return <<<SQL
 SELECT VM.NRVINCULOM||'-'||VM.NMVINCULOM AS VINCULO,
       TO_CHAR(FE.DTINIAQUISICAO,'DD/MM/YYYY') AS INICIO_AQUISICAO,
       TO_CHAR(FE.DTFIMAQUISICAO,'DD/MM/YYYY') AS FIM_AQUISICAO,
       TO_CHAR(ADD_MONTHS(FE.DTINIAQUISICAO,23),'DD/MM/YYYY') DATA_LIMITE,
       EH.NRESTRUTURAM,
       EH.NMESTRUTURAH,
       CP.CDCOMUNICAPARC
  FROM GPE_VINCULOM VM
  JOIN GPE_VINCULOH VH ON VH.NRORG = VM.NRORG
                      AND VH.NRVINCULOM = VM.NRVINCULOM
                      AND VH.DTMESCOMPETENC = (SELECT MAX(H1.DTMESCOMPETENC) FROM GPE_VINCULOH H1
                                                WHERE H1.NRORG = VH.NRORG
                                                AND VM.NRTIPOVINCULOM < 11
                                                  AND H1.NRVINCULOM = VH.NRVINCULOM
                                                  AND H1.DTMESCOMPETENC <= SYSDATE)
    LEFT JOIN ESTRUTURAH EH ON 
        EH.NRORG = VM.NRORG AND   
        EH.NRESTRUTURAM = VH.NRESTRUTGEREN AND
        EH.DTMESCOMPETENC = (SELECT MAX(EHH.DTMESCOMPETENC) FROM ESTRUTURAH EHH WHERE                            
                            EH.NRORG = EHH.NRORG AND
                            EHH.NRESTRUTURAM = EH.NRESTRUTURAM                            
                            AND EHH.DTMESCOMPETENC <= SYSDATE)                              
    LEFT JOIN COMUNICAPARC CP ON 
    CP.NRORG = VM.NRORG AND 
    CP.NRPARCNEGOCIO = EH.NRPARCRESPINF 
    AND CP.CDFORMACOMU = '05'               
  JOIN FPA_FERIAS FE ON FE.NRORG = VM.NRORG
                    AND FE.NRVINCULOM = VM.NRVINCULOM                        
 WHERE ADD_MONTHS(FE.DTINIAQUISICAO,23) BETWEEN SYSDATE AND ADD_MONTHS(SYSDATE,3)
   AND FE.IDCONTROLFERIAS IN ('ADQUIRIDO', 'GOZADO_PARCIAL')
   AND VM.DTRESCISAOVINC IS NULL
   AND VM.NRORG = :P_NRORG
 ORDER BY ADD_MONTHS(FE.DTINIAQUISICAO,23)
SQL;
    }

    public static function getQueryFuncionario2PeriodosAdquiridos()
    {
        return <<<SQL
SELECT VM.NRVINCULOM||'-'||VM.NMVINCULOM AS VINCULO,
       COUNT(FE.NRFERIAS) AS PERIODOS
  FROM GPE_VINCULOM VM
  JOIN FPA_FERIAS FE ON FE.NRORG = VM.NRORG
                    AND FE.NRVINCULOM = VM.NRVINCULOM
 WHERE FE.IDCONTROLFERIAS = 'ADQUIRIDO'
   AND VM.DTRESCISAOVINC IS NULL
   AND VM.NRORG = :P_NRORG
HAVING COUNT(FE.NRFERIAS) > 1
 GROUP BY VM.NRVINCULOM, VM.NMVINCULOM
 ORDER BY VM.NMVINCULOM
SQL;
    }

    public static function getQueryFeriasAdquiridasEmAberto()
    {
        return <<<SQL
SELECT VM.NRVINCULOM||'-'||VM.NMVINCULOM AS VINCULO,
       TO_CHAR(FE.DTINIAQUISICAO,'DD/MM/YYYY') AS INICIO_AQUISICAO,
       TO_CHAR(FE.DTFIMAQUISICAO,'DD/MM/YYYY') AS FIM_AQUISICAO
  FROM GPE_VINCULOM VM
  JOIN FPA_FERIAS FE ON FE.NRORG = VM.NRORG
                    AND FE.NRVINCULOM = VM.NRVINCULOM
 WHERE TRUNC( FE.DTFIMAQUISICAO, 'MM' ) < TRUNC( SYSDATE, 'MM')
   AND FE.IDCONTROLFERIAS = 'ABERTO'
   AND VM.DTRESCISAOVINC IS NULL
   AND VM.NRORG = :P_NRORG
 ORDER BY VM.NMVINCULOM, FE.DTINIAQUISICAO
SQL;
    }

    public static function getQueryContratoAVencer10Dias()
    {
        return <<<SQL
 SELECT VM.NRVINCULOM||'-'||VM.NMVINCULOM AS VINCULO,
       TO_CHAR(VH.DTFIMCONTRDETERMIN,'DD/MM/YYYY') AS FIM_CONTRATO,
       EH.NRESTRUTURAM,
       EH.NMESTRUTURAH,
       CP.CDCOMUNICAPARC
  FROM GPE_VINCULOM VM
  JOIN GPE_VINCULOH VH ON VH.NRORG = VM.NRORG
                      AND VH.NRVINCULOM = VM.NRVINCULOM
                      AND VH.DTMESCOMPETENC = (SELECT MAX(H1.DTMESCOMPETENC) FROM GPE_VINCULOH H1
                                                WHERE H1.NRORG = VH.NRORG
                                                  AND H1.NRVINCULOM = VH.NRVINCULOM
                                                  AND H1.DTMESCOMPETENC <= SYSDATE)
    LEFT JOIN ESTRUTURAH EH ON 
        EH.NRORG = VM.NRORG AND   
        EH.NRESTRUTURAM = VH.NRESTRUTGEREN AND
        EH.DTMESCOMPETENC = (SELECT MAX(EHH.DTMESCOMPETENC) FROM ESTRUTURAH EHH WHERE                            
                            EH.NRORG = EHH.NRORG AND
                            EHH.NRESTRUTURAM = EH.NRESTRUTURAM                            
                            AND EHH.DTMESCOMPETENC <= SYSDATE)                              
    LEFT JOIN COMUNICAPARC CP ON 
    CP.NRORG = VM.NRORG AND 
    CP.NRPARCNEGOCIO = EH.NRPARCRESPINF 
    AND CP.CDFORMACOMU = '05'                      
 WHERE VM.DTRESCISAOVINC IS NULL
   AND VH.DTFIMCONTRDETERMIN IS NOT NULL
   AND VH.DTFIMCONTRDETERMIN BETWEEN SYSDATE AND SYSDATE+10
   AND VM.NRORG = :P_NRORG
 ORDER BY VH.DTFIMCONTRDETERMIN
SQL;
    }

    public static function getQueryRescisãoNaoCalculada()
    {
        return <<<SQL
SELECT VM.NRVINCULOM||'-'||VM.NMVINCULOM AS VINCULO,
       TO_CHAR(VM.DTRESCISAOVINC,'DD/MM/YYYY') AS DATA_RESCISAO
  FROM GPE_VINCULOM VM
   WHERE TO_CHAR(VM.DTRESCISAOVINC,'MMYYYY') = TO_CHAR(SYSDATE,'MMYYYY')
   AND NOT EXISTS (SELECT * FROM FPA_ITECALCFOLHA IC
                    WHERE IC.NRORG = VM.NRORG
                      AND IC.NRVINCULOM = VM.NRVINCULOM
                      AND IC.NREVENTOM = 3050)
   AND VM.NRORG = :P_NRORG
 ORDER BY VM.NMVINCULOM
SQL;
    }

    public static function getQueryFeriasNaoCalculadas()
    {
        return <<<SQL
SELECT RES.NRVINCULOM||'-'||RES.NMVINCULOM AS VINCULO
FROM (SELECT VM.NRORG, VM.NRVINCULOM, VM.NMVINCULOM, GO.DTINIGOZOFERIAS, GO.DTFIMGOZOFERIAS, MAX(GO.DTINIGOZOFERIAS) OVER (PARTITION BY VM.NRVINCULOM) DTINIGOZOFERIAS_MAX
      FROM GPE_VINCULOM VM
      JOIN FPA_FERIAS FE ON FE.NRORG = VM.NRORG
                        AND FE.NRVINCULOM = VM.NRVINCULOM
      JOIN FPA_GOZOFERIAS GO ON GO.NRORG = FE.NRORG
                            AND GO.NRFERIAS = FE.NRFERIAS
      WHERE VM.DTRESCISAOVINC IS NULL

       AND VM.NRORG = :P_NRORG
      ORDER BY VM.NMVINCULOM
) RES
WHERE RES.DTINIGOZOFERIAS = RES.DTINIGOZOFERIAS_MAX 
  AND NOT EXISTS ( SELECT 1 FROM FPA_ITECALCFOLHA IC
                   JOIN FPA_CALCULOFOLHA CF ON CF.NRORG = IC.NRORG
                                           AND CF.NRCALCULOFOLHA = IC.NRCALCULOFOLHA
                                           AND CF.DTOCORRENCIA BETWEEN ADD_MONTHS( TRUNC( RES.DTINIGOZOFERIAS, 'MM' ), -2)
                                                                   AND TRUNC( RES.DTINIGOZOFERIAS, 'MM' )
                    WHERE IC.NRORG      = RES.NRORG
                      AND IC.NRVINCULOM = RES.NRVINCULOM
                      AND IC.NREVENTOM  IN (3030, 3050)
                      AND CF.NRTIPOMOVIMENT = 2 )
SQL;
    }

    public static function getQueryLicencaMaternidadeVencer10Dias()
    {
        return <<<SQL
SELECT VM.NRVINCULOM||'-'||VM.NMVINCULOM AS VINCULO,
       TO_CHAR(SF.DTFIMSITUFUNC,'DD/MM/YYYY') AS DATA_FINAL,
       EH.NRESTRUTURAM,
       EH.NMESTRUTURAH,
       CP.CDCOMUNICAPARC
  FROM GPE_VINCULOM VM
  JOIN GPE_VINCULOH VH ON 
    VH.NRORG = VM.NRORG AND
    VH.NRVINCULOM = VM.NRVINCULOM AND
    VH.DTMESCOMPETENC = (SELECT MAX(VHH.DTMESCOMPETENC) FROM GPE_VINCULOH VHH WHERE                            
                            VH.NRORG = VHH.NRORG AND
                            VHH.NRVINCULOM = VH.NRVINCULOM                            
                            AND VHH.DTMESCOMPETENC <= SYSDATE)    
  LEFT JOIN ESTRUTURAH EH ON 
        EH.NRORG = VM.NRORG AND   
        EH.NRESTRUTURAM = VH.NRESTRUTGEREN AND
        EH.DTMESCOMPETENC = (SELECT MAX(EHH.DTMESCOMPETENC) FROM ESTRUTURAH EHH WHERE                            
                            EH.NRORG = EHH.NRORG AND
                            EHH.NRESTRUTURAM = EH.NRESTRUTURAM                            
                            AND EHH.DTMESCOMPETENC <= SYSDATE)                              
    LEFT JOIN COMUNICAPARC CP ON 
    CP.NRORG = VM.NRORG AND 
    CP.NRPARCNEGOCIO = EH.NRPARCRESPINF
    AND CP.CDFORMACOMU = '05'
  JOIN GPE_ALTESITUFUNC SF ON SF.NRORG = VM.NRORG
                          AND SF.NRVINCULOM = VM.NRVINCULOM
 WHERE VM.DTRESCISAOVINC IS NULL
   AND SF.NRMOTIVOAFASTA = 3
   AND SF.DTFIMSITUFUNC BETWEEN SYSDATE-30 AND SYSDATE+10
   AND VM.NRORG = :P_NRORG
 ORDER BY SF.DTFIMSITUFUNC, VM.NMVINCULOM        
SQL;
    }

    public static function getQueryFuncionarioSemEscalaTrabalho()
    {
        return <<<SQL
SELECT VM.NRVINCULOM||'-'||VM.NMVINCULOM AS VINCULO
  FROM GPE_VINCULOM VM
  JOIN GPE_VINCULOH VH ON VH.NRORG = VM.NRORG
                      AND VH.NRVINCULOM = VM.NRVINCULOM
                      AND VH.DTMESCOMPETENC = (SELECT MAX(H1.DTMESCOMPETENC) FROM GPE_VINCULOH H1
                                                WHERE H1.NRORG = VH.NRORG
                                                  AND H1.NRVINCULOM = VH.NRVINCULOM
                                                  AND H1.DTMESCOMPETENC <= SYSDATE)
 WHERE VM.DTRESCISAOVINC IS NULL
   AND VH.NRESCALATRABM IS NULL
   AND VM.NRORG = :P_NRORG
 ORDER BY VM.NMVINCULOM
SQL;
    }

    public static function getQueryFuncionarioSemCargoFuncao()
    {
        return <<<SQL
SELECT VM.NRVINCULOM||'-'||VM.NMVINCULOM AS VINCULO
  FROM GPE_VINCULOM VM
  JOIN GPE_VINCULOH VH ON VH.NRORG = VM.NRORG
                      AND VH.NRVINCULOM = VM.NRVINCULOM
                      AND VH.DTMESCOMPETENC = (SELECT MAX(H1.DTMESCOMPETENC) FROM GPE_VINCULOH H1
                                                WHERE H1.NRORG = VH.NRORG
                                                  AND H1.NRVINCULOM = VH.NRVINCULOM
                                                  AND H1.DTMESCOMPETENC <= SYSDATE)
 WHERE VM.DTRESCISAOVINC IS NULL
   AND (VH.NRCARGO IS NULL OR VH.NRFUNCAO IS NULL)
   AND VM.NRORG = :P_NRORG
 ORDER BY VM.NMVINCULOM
SQL;
    }

    public static function getQueryFuncionarioRetornouSituacaoNormal()
    {
        return <<<SQL
SELECT VM.NRVINCULOM||'-'||VM.NMVINCULOM AS VINCULO,
       SF.DTINISITUFUNC AS DATA_RETORNO
  FROM GPE_VINCULOM VM
  JOIN GPE_ALTESITUFUNC SF ON SF.NRORG = VM.NRORG
                          AND SF.NRVINCULOM = VM.NRVINCULOM
 WHERE VM.DTRESCISAOVINC IS NULL
   AND SF.NRSITUFUNCM = 1
   AND TO_CHAR(SF.DTINISITUFUNC,'MMYYYY') = TO_CHAR(SYSDATE,'MMYYYY')
   AND VM.NRORG = :P_NRORG
 ORDER BY VM.NMVINCULOM
SQL;
    }

    public static function getQueryExameVencer15Dias()
    {
        return <<<SQL
SELECT VM.NRVINCULOM||'-'||VM.NMVINCULOM AS VINCULO,
       TO_CHAR(ADD_MONTHS(VM.DTEXAMEMEDICO,IPE.QTPERIODMESES),'DD/MM/YYYY') AS DATA_VENCIMENTO,
       EXA.NMEXAME AS EXAME
  FROM GPE_VINCULOM VM
  JOIN SST_PERFILEXAMEVINCULO PEV ON PEV.NRORG = VM.NRORG
                                 AND PEV.NRVINCULOM = VM.NRVINCULOM
                                 AND PEV.DTINIVIGENCIA <= SYSDATE
                                 AND (PEV.DTFIMVIGENCIA IS NULL OR PEV.DTFIMVIGENCIA >= SYSDATE+15)
  JOIN SST_PERFILEXAME PE ON PE.NRORG = PEV.NRORG
                         AND PE.NRPERFILEXAME = PEV.NRPERFILEXAME
                         AND PE.DTINIVIGENCIA <= SYSDATE
                         AND (PE.DTFIMVIGENCIA IS NULL OR PE.DTFIMVIGENCIA >= SYSDATE+15)
  JOIN SST_ITEMPERFILEXAME IPE ON IPE.NRORG = PEV.NRORG
                              AND IPE.NRPERFILEXAME = PEV.NRPERFILEXAME
                              AND IPE.DTINIVIGENCIA <= SYSDATE
                              AND (IPE.DTFIMVIGENCIA IS NULL OR IPE.DTFIMVIGENCIA >= SYSDATE+15)
  JOIN SST_EXAME EXA ON EXA.NRORG = IPE.NRORG
                  AND EXA.NREXAME = IPE.NREXAME
 WHERE ADD_MONTHS(VM.DTEXAMEMEDICO,IPE.QTPERIODMESES) BETWEEN SYSDATE AND SYSDATE+15
   AND VM.DTRESCISAOVINC IS NULL
   AND VM.DTEXAMEMEDICO IS NOT NULL
   AND VM.NRORG = :P_NRORG
UNION
SELECT VM.NRVINCULOM||'-'||VM.NMVINCULOM AS VINCULO,
       TO_CHAR(ADD_MONTHS(VM.DTEXAMEMEDICO,IPE.QTPERIODMESES),'DD/MM/YYYY') AS DATA_VENCIMENTO,
       EXA.NMEXAME AS EXAME
  FROM GPE_VINCULOM VM
  JOIN GPE_VINCULOH VH ON VH.NRORG = VM.NRORG
                      AND VH.NRVINCULOM = VM.NRVINCULOM
                      AND VH.DTMESCOMPETENC = (SELECT MAX(H1.DTMESCOMPETENC) FROM GPE_VINCULOH H1
                                                WHERE H1.NRORG = VH.NRORG
                                                  AND H1.NRVINCULOM = VH.NRVINCULOM
                                                  AND H1.DTMESCOMPETENC <= SYSDATE)
  JOIN SST_PERFILEXAMEOCUPACAO PEO ON PEO.NRORG = VH.NRORG
                                  AND PEO.NROCUPACAOM = VH.NRCARGO
                                  AND PEO.DTINIVIGENCIA <= SYSDATE
                                  AND (PEO.DTFIMVIGENCIA IS NULL OR PEO.DTFIMVIGENCIA >= SYSDATE+15)
  JOIN SST_PERFILEXAME PE ON PE.NRORG = PEO.NRORG
                         AND PE.NRPERFILEXAME = PEO.NRPERFILEXAME
                         AND PE.DTINIVIGENCIA <= SYSDATE
                         AND (PE.DTFIMVIGENCIA IS NULL OR PE.DTFIMVIGENCIA >= SYSDATE+15)
  JOIN SST_ITEMPERFILEXAME IPE ON IPE.NRORG = PEO.NRORG
                              AND IPE.NRPERFILEXAME = PEO.NRPERFILEXAME
                              AND IPE.DTINIVIGENCIA <= SYSDATE
                              AND (IPE.DTFIMVIGENCIA IS NULL OR IPE.DTFIMVIGENCIA >= SYSDATE+15)
  JOIN SST_EXAME EXA ON EXA.NRORG = IPE.NRORG
                  AND EXA.NREXAME = IPE.NREXAME
 WHERE ADD_MONTHS(VM.DTEXAMEMEDICO,IPE.QTPERIODMESES) BETWEEN SYSDATE AND SYSDATE+15
   AND VM.DTRESCISAOVINC IS NULL
   AND VM.DTEXAMEMEDICO IS NOT NULL
   AND VM.NRORG = :P_NRORG
UNION
SELECT VM.NRVINCULOM||'-'||VM.NMVINCULOM AS VINCULO,
       TO_CHAR(ADD_MONTHS(VM.DTEXAMEMEDICO,IPE.QTPERIODMESES),'DD/MM/YYYY') AS DATA_VENCIMENTO,
       EXA.NMEXAME AS EXAME
  FROM GPE_VINCULOM VM
  JOIN GPE_VINCULOH VH ON VH.NRORG = VM.NRORG
                      AND VH.NRVINCULOM = VM.NRVINCULOM
                      AND VH.DTMESCOMPETENC = (SELECT MAX(H1.DTMESCOMPETENC) FROM GPE_VINCULOH H1
                                                WHERE H1.NRORG = VH.NRORG
                                                  AND H1.NRVINCULOM = VH.NRVINCULOM
                                                  AND H1.DTMESCOMPETENC <= SYSDATE)
  JOIN SST_PERFILEXAMEESTRUTURA PEE ON PEE.NRORG = VH.NRORG
                                   AND (PEE.NRESTRUTURAM = VH.NRESTRUTLEGAL OR PEE.NRESTRUTURAM = VH.NRESTRUTGEREN OR PEE.NRESTRUTURAM = VH.NRESTRUTSIND)
                                   AND PEE.DTINIVIGENCIA <= SYSDATE
                                   AND (PEE.DTFIMVIGENCIA IS NULL OR PEE.DTFIMVIGENCIA >= SYSDATE+15)
  JOIN SST_PERFILEXAME PE ON PE.NRORG = PEE.NRORG
                         AND PE.NRPERFILEXAME = PEE.NRPERFILEXAME
                         AND PE.DTINIVIGENCIA <= SYSDATE
                         AND (PE.DTFIMVIGENCIA IS NULL OR PE.DTFIMVIGENCIA >= SYSDATE+15)
  JOIN SST_ITEMPERFILEXAME IPE ON IPE.NRORG = PEE.NRORG
                              AND IPE.NRPERFILEXAME = PEE.NRPERFILEXAME
                              AND IPE.DTINIVIGENCIA <= SYSDATE
                              AND (IPE.DTFIMVIGENCIA IS NULL OR IPE.DTFIMVIGENCIA >= SYSDATE+15)
  JOIN SST_EXAME EXA ON EXA.NRORG = IPE.NRORG
                  AND EXA.NREXAME = IPE.NREXAME
 WHERE ADD_MONTHS(VM.DTEXAMEMEDICO,IPE.QTPERIODMESES) BETWEEN SYSDATE AND SYSDATE+15
   AND VM.DTRESCISAOVINC IS NULL
   AND VM.DTEXAMEMEDICO IS NOT NULL
   AND VM.NRORG = :P_NRORG
 ORDER BY 3
SQL;
    }

    public static function getQueryEPIVencer15Dias()
    {
        return <<<SQL
SELECT VM.NRVINCULOM||'-'||VM.NMVINCULOM AS VINCULO,
       TO_CHAR(ADD_MONTHS(VM.DTENTREGAEPI,IPE.QTPERIODMESES),'DD/MM/YYYY') AS DATA_VENCIMENTO,
       EPI.NMEPI AS EPI
  FROM GPE_VINCULOM VM
  JOIN SST_PERFILEPIVINCULO PEV ON PEV.NRORG = VM.NRORG
                               AND PEV.NRVINCULOM = VM.NRVINCULOM
                               AND PEV.DTINIVIGENCIA <= SYSDATE
                               AND (PEV.DTFIMVIGENCIA IS NULL OR PEV.DTFIMVIGENCIA >= SYSDATE+15)
  JOIN SST_PERFILEPI PE ON PE.NRORG = PEV.NRORG
                       AND PE.NRPERFILEPI = PEV.NRPERFILEPI
                       AND PE.DTINIVIGENCIA <= SYSDATE
                       AND (PE.DTFIMVIGENCIA IS NULL OR PE.DTFIMVIGENCIA >= SYSDATE+15)
  JOIN SST_ITEMPERFILEPI IPE ON IPE.NRORG = PEV.NRORG
                            AND IPE.NRPERFILEPI = PEV.NRPERFILEPI
                            AND IPE.DTINIVIGENCIA <= SYSDATE
                            AND (IPE.DTFIMVIGENCIA IS NULL OR IPE.DTFIMVIGENCIA >= SYSDATE+15)
  JOIN SST_EPI EPI ON EPI.NRORG = IPE.NRORG
                  AND EPI.NREPI = IPE.NREPI
 WHERE ADD_MONTHS(VM.DTENTREGAEPI,IPE.QTPERIODMESES) BETWEEN SYSDATE AND SYSDATE+15
   AND VM.DTRESCISAOVINC IS NULL
   AND VM.DTENTREGAEPI IS NOT NULL
   AND VM.NRORG = :P_NRORG
UNION
SELECT VM.NRVINCULOM||'-'||VM.NMVINCULOM AS VINCULO,
       TO_CHAR(ADD_MONTHS(VM.DTENTREGAEPI,IPE.QTPERIODMESES),'DD/MM/YYYY') AS DATA_VENCIMENTO,
       EPI.NMEPI AS EPI
  FROM GPE_VINCULOM VM
  JOIN GPE_VINCULOH VH ON VH.NRORG = VM.NRORG
                      AND VH.NRVINCULOM = VM.NRVINCULOM
                      AND VH.DTMESCOMPETENC = (SELECT MAX(H1.DTMESCOMPETENC) FROM GPE_VINCULOH H1
                                                WHERE H1.NRORG = VH.NRORG
                                                  AND H1.NRVINCULOM = VH.NRVINCULOM
                                                  AND H1.DTMESCOMPETENC <= SYSDATE)
  JOIN SST_PERFILEPIOCUPACAO PEO ON PEO.NRORG = VH.NRORG
                               AND PEO.NROCUPACAOM = VH.NRCARGO
                               AND PEO.DTINIVIGENCIA <= SYSDATE
                               AND (PEO.DTFIMVIGENCIA IS NULL OR PEO.DTFIMVIGENCIA >= SYSDATE+15)
  JOIN SST_PERFILEPI PE ON PE.NRORG = PEO.NRORG
                       AND PE.NRPERFILEPI = PEO.NRPERFILEPI
                       AND PE.DTINIVIGENCIA <= SYSDATE
                       AND (PE.DTFIMVIGENCIA IS NULL OR PE.DTFIMVIGENCIA >= SYSDATE+15)
  JOIN SST_ITEMPERFILEPI IPE ON IPE.NRORG = PEO.NRORG
                            AND IPE.NRPERFILEPI = PEO.NRPERFILEPI
                            AND IPE.DTINIVIGENCIA <= SYSDATE
                            AND (IPE.DTFIMVIGENCIA IS NULL OR IPE.DTFIMVIGENCIA >= SYSDATE+15)
  JOIN SST_EPI EPI ON EPI.NRORG = IPE.NRORG
                  AND EPI.NREPI = IPE.NREPI
 WHERE ADD_MONTHS(VM.DTENTREGAEPI,IPE.QTPERIODMESES) BETWEEN SYSDATE AND SYSDATE+15
   AND VM.DTRESCISAOVINC IS NULL
   AND VM.DTENTREGAEPI IS NOT NULL
   AND VM.NRORG = :P_NRORG
UNION
SELECT VM.NRVINCULOM||'-'||VM.NMVINCULOM AS VINCULO,
       TO_CHAR(ADD_MONTHS(VM.DTENTREGAEPI,IPE.QTPERIODMESES),'DD/MM/YYYY') AS DATA_VENCIMENTO,
       EPI.NMEPI AS EPI
  FROM GPE_VINCULOM VM
  JOIN GPE_VINCULOH VH ON VH.NRORG = VM.NRORG
                      AND VH.NRVINCULOM = VM.NRVINCULOM
                      AND VH.DTMESCOMPETENC = (SELECT MAX(H1.DTMESCOMPETENC) FROM GPE_VINCULOH H1
                                                WHERE H1.NRORG = VH.NRORG
                                                  AND H1.NRVINCULOM = VH.NRVINCULOM
                                                  AND H1.DTMESCOMPETENC <= SYSDATE)
  JOIN SST_PERFILEPIESTRUTURA PEE ON PEE.NRORG = VH.NRORG
                               AND (PEE.NRESTRUTURAM = VH.NRESTRUTLEGAL OR PEE.NRESTRUTURAM = VH.NRESTRUTGEREN OR PEE.NRESTRUTURAM = VH.NRESTRUTSIND)
                               AND PEE.DTINIVIGENCIA <= SYSDATE
                               AND (PEE.DTFIMVIGENCIA IS NULL OR PEE.DTFIMVIGENCIA >= SYSDATE+15)
  JOIN SST_PERFILEPI PE ON PE.NRORG = PEE.NRORG
                       AND PE.NRPERFILEPI = PEE.NRPERFILEPI
                       AND PE.DTINIVIGENCIA <= SYSDATE
                       AND (PE.DTFIMVIGENCIA IS NULL OR PE.DTFIMVIGENCIA >= SYSDATE+15)
  JOIN SST_ITEMPERFILEPI IPE ON IPE.NRORG = PEE.NRORG
                            AND IPE.NRPERFILEPI = PEE.NRPERFILEPI
                            AND IPE.DTINIVIGENCIA <= SYSDATE
                            AND (IPE.DTFIMVIGENCIA IS NULL OR IPE.DTFIMVIGENCIA >= SYSDATE+15)
  JOIN SST_EPI EPI ON EPI.NRORG = IPE.NRORG
                  AND EPI.NREPI = IPE.NREPI
 WHERE ADD_MONTHS(VM.DTENTREGAEPI,IPE.QTPERIODMESES) BETWEEN SYSDATE AND SYSDATE+15
   AND VM.DTRESCISAOVINC IS NULL
   AND VM.DTENTREGAEPI IS NOT NULL
   AND VM.NRORG = :P_NRORG
 ORDER BY 3
SQL;
    }

    public static function getQueryExameVencido()
    {
        return <<<SQL
SELECT VM.NRVINCULOM||'-'||VM.NMVINCULOM AS VINCULO,
       TO_CHAR(ADD_MONTHS(VM.DTEXAMEMEDICO,IPE.QTPERIODMESES),'DD/MM/YYYY') AS DATA_VENCIMENTO,
       EXA.NMEXAME AS EXAME
  FROM GPE_VINCULOM VM
  JOIN SST_PERFILEXAMEVINCULO PEV ON PEV.NRORG = VM.NRORG
                                 AND PEV.NRVINCULOM = VM.NRVINCULOM
                                 AND PEV.DTINIVIGENCIA <= SYSDATE
                                 AND (PEV.DTFIMVIGENCIA IS NULL OR PEV.DTFIMVIGENCIA >= SYSDATE+15)
  JOIN SST_PERFILEXAME PE ON PE.NRORG = PEV.NRORG
                         AND PE.NRPERFILEXAME = PEV.NRPERFILEXAME
                         AND PE.DTINIVIGENCIA <= SYSDATE
                         AND (PE.DTFIMVIGENCIA IS NULL OR PE.DTFIMVIGENCIA >= SYSDATE+15)
  JOIN SST_ITEMPERFILEXAME IPE ON IPE.NRORG = PEV.NRORG
                              AND IPE.NRPERFILEXAME = PEV.NRPERFILEXAME
                              AND IPE.DTINIVIGENCIA <= SYSDATE
                              AND (IPE.DTFIMVIGENCIA IS NULL OR IPE.DTFIMVIGENCIA >= SYSDATE+15)
  JOIN SST_EXAME EXA ON EXA.NRORG = IPE.NRORG
                  AND EXA.NREXAME = IPE.NREXAME
 WHERE ADD_MONTHS(VM.DTEXAMEMEDICO,IPE.QTPERIODMESES) < TRUNC(SYSDATE)
   AND VM.DTRESCISAOVINC IS NULL
   AND VM.DTEXAMEMEDICO IS NOT NULL
   AND VM.NRORG = :P_NRORG
UNION
SELECT VM.NRVINCULOM||'-'||VM.NMVINCULOM AS VINCULO,
       TO_CHAR(ADD_MONTHS(VM.DTEXAMEMEDICO,IPE.QTPERIODMESES),'DD/MM/YYYY') AS DATA_VENCIMENTO,
       EXA.NMEXAME AS EXAME
  FROM GPE_VINCULOM VM
  JOIN GPE_VINCULOH VH ON VH.NRORG = VM.NRORG
                      AND VH.NRVINCULOM = VM.NRVINCULOM
                      AND VH.DTMESCOMPETENC = (SELECT MAX(H1.DTMESCOMPETENC) FROM GPE_VINCULOH H1
                                                WHERE H1.NRORG = VH.NRORG
                                                  AND H1.NRVINCULOM = VH.NRVINCULOM
                                                  AND H1.DTMESCOMPETENC <= SYSDATE)
  JOIN SST_PERFILEXAMEOCUPACAO PEO ON PEO.NRORG = VH.NRORG
                                  AND PEO.NROCUPACAOM = VH.NRCARGO
                                  AND PEO.DTINIVIGENCIA <= SYSDATE
                                  AND (PEO.DTFIMVIGENCIA IS NULL OR PEO.DTFIMVIGENCIA >= SYSDATE+15)
  JOIN SST_PERFILEXAME PE ON PE.NRORG = PEO.NRORG
                         AND PE.NRPERFILEXAME = PEO.NRPERFILEXAME
                         AND PE.DTINIVIGENCIA <= SYSDATE
                         AND (PE.DTFIMVIGENCIA IS NULL OR PE.DTFIMVIGENCIA >= SYSDATE+15)
  JOIN SST_ITEMPERFILEXAME IPE ON IPE.NRORG = PEO.NRORG
                              AND IPE.NRPERFILEXAME = PEO.NRPERFILEXAME
                              AND IPE.DTINIVIGENCIA <= SYSDATE
                              AND (IPE.DTFIMVIGENCIA IS NULL OR IPE.DTFIMVIGENCIA >= SYSDATE+15)
  JOIN SST_EXAME EXA ON EXA.NRORG = IPE.NRORG
                  AND EXA.NREXAME = IPE.NREXAME
 WHERE ADD_MONTHS(VM.DTEXAMEMEDICO,IPE.QTPERIODMESES) < TRUNC(SYSDATE)
   AND VM.DTRESCISAOVINC IS NULL
   AND VM.DTEXAMEMEDICO IS NOT NULL
   AND VM.NRORG = :P_NRORG
UNION
SELECT VM.NRVINCULOM||'-'||VM.NMVINCULOM AS VINCULO,
       TO_CHAR(ADD_MONTHS(VM.DTEXAMEMEDICO,IPE.QTPERIODMESES),'DD/MM/YYYY') AS DATA_VENCIMENTO,
       EXA.NMEXAME AS EXAME
  FROM GPE_VINCULOM VM
  JOIN GPE_VINCULOH VH ON VH.NRORG = VM.NRORG
                      AND VH.NRVINCULOM = VM.NRVINCULOM
                      AND VH.DTMESCOMPETENC = (SELECT MAX(H1.DTMESCOMPETENC) FROM GPE_VINCULOH H1
                                                WHERE H1.NRORG = VH.NRORG
                                                  AND H1.NRVINCULOM = VH.NRVINCULOM
                                                  AND H1.DTMESCOMPETENC <= SYSDATE)
  JOIN SST_PERFILEXAMEESTRUTURA PEE ON PEE.NRORG = VH.NRORG
                                   AND (PEE.NRESTRUTURAM = VH.NRESTRUTLEGAL OR PEE.NRESTRUTURAM = VH.NRESTRUTGEREN OR PEE.NRESTRUTURAM = VH.NRESTRUTSIND)
                                   AND PEE.DTINIVIGENCIA <= SYSDATE
                                   AND (PEE.DTFIMVIGENCIA IS NULL OR PEE.DTFIMVIGENCIA >= SYSDATE+15)
  JOIN SST_PERFILEXAME PE ON PE.NRORG = PEE.NRORG
                         AND PE.NRPERFILEXAME = PEE.NRPERFILEXAME
                         AND PE.DTINIVIGENCIA <= SYSDATE
                         AND (PE.DTFIMVIGENCIA IS NULL OR PE.DTFIMVIGENCIA >= SYSDATE+15)
  JOIN SST_ITEMPERFILEXAME IPE ON IPE.NRORG = PEE.NRORG
                              AND IPE.NRPERFILEXAME = PEE.NRPERFILEXAME
                              AND IPE.DTINIVIGENCIA <= SYSDATE
                              AND (IPE.DTFIMVIGENCIA IS NULL OR IPE.DTFIMVIGENCIA >= SYSDATE+15)
  JOIN SST_EXAME EXA ON EXA.NRORG = IPE.NRORG
                  AND EXA.NREXAME = IPE.NREXAME
 WHERE ADD_MONTHS(VM.DTEXAMEMEDICO,IPE.QTPERIODMESES) < TRUNC(SYSDATE)
   AND VM.DTRESCISAOVINC IS NULL
   AND VM.DTEXAMEMEDICO IS NOT NULL
   AND VM.NRORG = :P_NRORG
 ORDER BY 3
SQL;
    }

    public static function getQueryEPIVencido()
    {
        return <<<SQL
SELECT VM.NRVINCULOM||'-'||VM.NMVINCULOM AS VINCULO,
       TO_CHAR(ADD_MONTHS(VM.DTENTREGAEPI,IPE.QTPERIODMESES),'DD/MM/YYYY') AS DATA_VENCIMENTO,
       EPI.NMEPI AS EPI
  FROM GPE_VINCULOM VM
  JOIN SST_PERFILEPIVINCULO PEV ON PEV.NRORG = VM.NRORG
                               AND PEV.NRVINCULOM = VM.NRVINCULOM
                               AND PEV.DTINIVIGENCIA <= SYSDATE
                               AND (PEV.DTFIMVIGENCIA IS NULL OR PEV.DTFIMVIGENCIA >= SYSDATE+15)
  JOIN SST_PERFILEPI PE ON PE.NRORG = PEV.NRORG
                       AND PE.NRPERFILEPI = PEV.NRPERFILEPI
                       AND PE.DTINIVIGENCIA <= SYSDATE
                       AND (PE.DTFIMVIGENCIA IS NULL OR PE.DTFIMVIGENCIA >= SYSDATE+15)
  JOIN SST_ITEMPERFILEPI IPE ON IPE.NRORG = PEV.NRORG
                            AND IPE.NRPERFILEPI = PEV.NRPERFILEPI
                            AND IPE.DTINIVIGENCIA <= SYSDATE
                            AND (IPE.DTFIMVIGENCIA IS NULL OR IPE.DTFIMVIGENCIA >= SYSDATE+15)
  JOIN SST_EPI EPI ON EPI.NRORG = IPE.NRORG
                  AND EPI.NREPI = IPE.NREPI
 WHERE ADD_MONTHS(VM.DTENTREGAEPI,IPE.QTPERIODMESES) < TRUNC(SYSDATE)
   AND VM.DTRESCISAOVINC IS NULL
   AND VM.DTENTREGAEPI IS NOT NULL
   AND VM.NRORG = :P_NRORG
UNION
SELECT VM.NRVINCULOM||'-'||VM.NMVINCULOM AS VINCULO,
       TO_CHAR(ADD_MONTHS(VM.DTENTREGAEPI,IPE.QTPERIODMESES),'DD/MM/YYYY') AS DATA_VENCIMENTO,
       EPI.NMEPI AS EPI
  FROM GPE_VINCULOM VM
  JOIN GPE_VINCULOH VH ON VH.NRORG = VM.NRORG
                      AND VH.NRVINCULOM = VM.NRVINCULOM
                      AND VH.DTMESCOMPETENC = (SELECT MAX(H1.DTMESCOMPETENC) FROM GPE_VINCULOH H1
                                                WHERE H1.NRORG = VH.NRORG
                                                  AND H1.NRVINCULOM = VH.NRVINCULOM
                                                  AND H1.DTMESCOMPETENC <= SYSDATE)
  JOIN SST_PERFILEPIOCUPACAO PEO ON PEO.NRORG = VH.NRORG
                               AND PEO.NROCUPACAOM = VH.NRCARGO
                               AND PEO.DTINIVIGENCIA <= SYSDATE
                               AND (PEO.DTFIMVIGENCIA IS NULL OR PEO.DTFIMVIGENCIA >= SYSDATE+15)
  JOIN SST_PERFILEPI PE ON PE.NRORG = PEO.NRORG
                       AND PE.NRPERFILEPI = PEO.NRPERFILEPI
                       AND PE.DTINIVIGENCIA <= SYSDATE
                       AND (PE.DTFIMVIGENCIA IS NULL OR PE.DTFIMVIGENCIA >= SYSDATE+15)
  JOIN SST_ITEMPERFILEPI IPE ON IPE.NRORG = PEO.NRORG
                            AND IPE.NRPERFILEPI = PEO.NRPERFILEPI
                            AND IPE.DTINIVIGENCIA <= SYSDATE
                            AND (IPE.DTFIMVIGENCIA IS NULL OR IPE.DTFIMVIGENCIA >= SYSDATE+15)
  JOIN SST_EPI EPI ON EPI.NRORG = IPE.NRORG
                  AND EPI.NREPI = IPE.NREPI
 WHERE ADD_MONTHS(VM.DTENTREGAEPI,IPE.QTPERIODMESES) < TRUNC(SYSDATE)
   AND VM.DTRESCISAOVINC IS NULL
   AND VM.DTENTREGAEPI IS NOT NULL
   AND VM.NRORG = :P_NRORG
UNION
SELECT VM.NRVINCULOM||'-'||VM.NMVINCULOM AS VINCULO,
       TO_CHAR(ADD_MONTHS(VM.DTENTREGAEPI,IPE.QTPERIODMESES),'DD/MM/YYYY') AS DATA_VENCIMENTO,
       EPI.NMEPI AS EPI
  FROM GPE_VINCULOM VM
  JOIN GPE_VINCULOH VH ON VH.NRORG = VM.NRORG
                      AND VH.NRVINCULOM = VM.NRVINCULOM
                      AND VH.DTMESCOMPETENC = (SELECT MAX(H1.DTMESCOMPETENC) FROM GPE_VINCULOH H1
                                                WHERE H1.NRORG = VH.NRORG
                                                  AND H1.NRVINCULOM = VH.NRVINCULOM
                                                  AND H1.DTMESCOMPETENC <= SYSDATE)
  JOIN SST_PERFILEPIESTRUTURA PEE ON PEE.NRORG = VH.NRORG
                               AND (PEE.NRESTRUTURAM = VH.NRESTRUTLEGAL OR PEE.NRESTRUTURAM = VH.NRESTRUTGEREN OR PEE.NRESTRUTURAM = VH.NRESTRUTSIND)
                               AND PEE.DTINIVIGENCIA <= SYSDATE
                               AND (PEE.DTFIMVIGENCIA IS NULL OR PEE.DTFIMVIGENCIA >= SYSDATE+15)
  JOIN SST_PERFILEPI PE ON PE.NRORG = PEE.NRORG
                       AND PE.NRPERFILEPI = PEE.NRPERFILEPI
                       AND PE.DTINIVIGENCIA <= SYSDATE
                       AND (PE.DTFIMVIGENCIA IS NULL OR PE.DTFIMVIGENCIA >= SYSDATE+15)
  JOIN SST_ITEMPERFILEPI IPE ON IPE.NRORG = PEE.NRORG
                            AND IPE.NRPERFILEPI = PEE.NRPERFILEPI
                            AND IPE.DTINIVIGENCIA <= SYSDATE
                            AND (IPE.DTFIMVIGENCIA IS NULL OR IPE.DTFIMVIGENCIA >= SYSDATE+15)
  JOIN SST_EPI EPI ON EPI.NRORG = IPE.NRORG
                  AND EPI.NREPI = IPE.NREPI
 WHERE ADD_MONTHS(VM.DTENTREGAEPI,IPE.QTPERIODMESES) < TRUNC(SYSDATE)
   AND VM.DTRESCISAOVINC IS NULL
   AND VM.DTENTREGAEPI IS NOT NULL
   AND VM.NRORG = :P_NRORG
 ORDER BY 3
SQL;
    }

    public static function getQueryDataBaseSindicato()
    {
        return <<<SQL
SELECT
  TO_CHAR(RES.DTBASESINDICAL_AT, 'DD/MM/YYYY') DTBASESINDICAL_AT,
  CASE
    WHEN RES.DTBASESINDICAL_AT - TRUNC(SYSDATE, 'DD') = 0
      THEN 'Hoje'
    WHEN RES.DTBASESINDICAL_AT - TRUNC(SYSDATE, 'DD') = 1
      THEN 'Amanhã'
    ELSE (RES.DTBASESINDICAL_AT - TRUNC(SYSDATE, 'DD')) || ' dias restantes'
  END DIAS_RESTANTES,
  RES.NRESTRUTURAM,
  RES.NMESTRUTURAM
FROM (SELECT
        CASE
          WHEN TO_DATE(TO_CHAR(DTBASESINDICAL, 'DD/MM/') || TO_CHAR(SYSDATE, 'YYYY')) < SYSDATE
            THEN TO_DATE(TO_CHAR(DTBASESINDICAL, 'DD/MM/') || (TO_CHAR(SYSDATE, 'YYYY') + 1))
          ELSE TO_DATE(TO_CHAR(PS.DTBASESINDICAL, 'DD/MM/') || TO_CHAR(SYSDATE, 'YYYY'))
        END DTBASESINDICAL_AT,
        EM.NRESTRUTURAM,
        EM.NMESTRUTURAM
      FROM FPA_PARAMSINDICATO PS
      JOIN ESTRUTURAM EM ON EM.NRORG        = PS.NRORG
                        AND EM.NRESTRUTURAM = PS.NRESTRUTURAM
      WHERE PS.DTBASESINDICAL IS NOT NULL AND PS.NRORG = :P_NRORG
) RES
WHERE RES.DTBASESINDICAL_AT - TRUNC(SYSDATE, 'DD') <= 30
ORDER BY RES.DTBASESINDICAL_AT
SQL;
    }

    public static function getQueryFuncionario2PeriodosAbertos()
    {
        return <<<SQL
SELECT VM.NRVINCULOM||'-'||VM.NMVINCULOM AS VINCULO,
       COUNT(FE.NRFERIAS) AS PERIODOS
  FROM GPE_VINCULOM VM
  JOIN FPA_FERIAS FE ON FE.NRORG = VM.NRORG
   AND FE.NRVINCULOM = VM.NRVINCULOM
 WHERE FE.IDCONTROLFERIAS = 'ABERTO'
   AND (VM.DTRESCISAOVINC IS NULL OR VM.DTRESCISAOVINC >= ADD_MONTHS(LAST_DAY(TRUNC(SYSDATE))+1,-1))
   AND VM.NRORG = :P_NRORG
HAVING COUNT(FE.NRFERIAS) > 1
 GROUP BY VM.NRVINCULOM, VM.NMVINCULOM
 ORDER BY VM.NMVINCULOM
SQL;
    }
}